Module console

Module console 

The terminal device itself, independent of the inherited streams.

Functions

adopt_terminal_as_stdin
device
Opens the terminal this process is attached to.
report
Puts a message in front of the user, wherever it can still be seen.