pub struct Profile {
pub path: PathBuf,
pub label: String,
}Expand description
A profile file the integration can be written into.
Fields
path: PathBuflabel: StringHow to name this file when talking to the user.