Module store

Module store 

On-disk locations and readers for everything lore persists.

Modules

definitions
Reading command definition files and merging them into one library.
stats
Usage statistics and remembered placeholder values.

Functions

stats_database
The usage statistics database.
sync_dir
lore’s own clone of the repository the library syncs through.
user_library
The user’s editable command library.