On-disk locations and readers for everything lore persists.
Modules
- definitions
- Reading command definition files and merging them into one library.
- stats
- Usage statistics and remembered placeholder values.
Functions
- stats_
database - The usage statistics database.
- sync_
dir - lore’s own clone of the repository the library syncs through.
- user_
library - The user’s editable command library.