pub struct App { /* private fields */ }Implementations
Sourceimpl App
impl App
pub fn new( entries: Vec<Entry>, family: ShellFamily, stats: Stats, library: PathBuf, history: Vec<String>, now: i64, ) -> Result<Self>
pub fn query(&self) -> &str
pub fn mode(&self) -> &Mode
pub fn status(&self) -> Option<&str>
pub fn selected(&self) -> usize
pub fn matches(&self) -> usize
Sourcepub fn rows(&self) -> impl Iterator<Item = Row<'_>>
pub fn rows(&self) -> impl Iterator<Item = Row<'_>>
The entries currently on offer, best first.
pub fn selected_row(&self) -> Option<Row<'_>>
Sourcepub fn highlight(&self, haystack: &str) -> Vec<u32>
pub fn highlight(&self, haystack: &str) -> Vec<u32>
Highlights the query inside a haystack for the rows on screen.
pub fn on_key(&mut self, key: KeyEvent) -> Result<Option<Outcome>>
Sourcepub fn is_saved(&self, command: &str) -> bool
pub fn is_saved(&self, command: &str) -> bool
Whether the library already holds exactly this command for this shell.
Tags the entry being saved would get, for showing before it is saved.